#!/bin/bash
# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

# Copyright (c) DVIC.
# Distributed under the terms of the Modified BSD License.

YELLOW='\033[0;33m'
RED='\033[0;31m'
GREEN='\033[0;32m'
NC='\033[0m' # No Color

set -e

echo -e "[INIT] $GREEN Running Jupyter-lab DVIC specific version $NC"
BUILD_DATE=`cat < /etc/build_date`
echo -e "[INIT] $GREEN Build date: $BUILD_DATE $NC"

echo "Set disable_coredump false" | sudo tee /etc/sudo.conf

if [ $(id -u) != 0 ] ; then
  echo -e "[INIT] $YELLOW WARN: Not root. I hope `id -n -u` has access $NC"
fi

echo -e "[INIT] $GREEN Final user is $JUPYTERHUB_USER $NC"
NB_USER=$JUPYTERHUB_USER

if [[ "$JUPYTER_UID" != "" ]]; then
    echo -e "[INIT] $GREEN Final UID is $JUPYTER_UID $NC" 
    sudo groupadd --gid $JUPYTER_UID $NB_USER
    UID_OPT="--uid $JUPYTER_UID --gid $JUPYTER_UID"
else
    echo -e "[INIT] $YELLOW Final UID not set $NC"
fi
echo -e "[INIT] $GREEN Creating user $NC"
sudo useradd --create-home $NB_USER $UID_OPT

if [[ -d "$PERSISTED_PATH" ]]; then
    PERSISTED_MOUNT="/home/$NB_USER/persisted"
    echo -e "[INIT] $GREEN Persisted path is $PERSISTED_PATH Linking in $PERSISTED_MOUNT $NC"
    sudo ln -s "$PERSISTED_PATH" "$PERSISTED_MOUNT"
    sudo chown $NB_USER:$NB_USER /home/$NB_USER/persisted/ 
else
    echo -e "[INIT] $YELLOW No persisted path provided $NC"
fi

echo -e "[INIT] $GREEN Importing custom theme and user files $NC"
sudo mkdir -p /home/$NB_USER/.jupyter/lab/user-settings/@jupyterlab/apputils-extension
# sudo cp /etc/profile /home/$NB_USER/.profile
sudo cp /etc/jupyter/Welcome.md /home/$NB_USER
sudo cp /etc/jupyter/Bienvenue.md /home/$NB_USER
sudo cp /etc/jupyter/themes.jupyterlab-settings /home/$NB_USER/.jupyter/lab/user-settings/@jupyterlab/apputils-extension
sudo chown -R $NB_USER:$NB_USER /home/$NB_USER

echo -e "[INIT] $GREEN Appending tensorboard alias to .bashrc $NC"
echo "alias tensorboard='tensorboard --path_prefix=/jupyter/user/$NB_USER/tensorboard'" | sudo tee -a /home/$NB_USER/.bashrc

# Exec the specified command or crash
# if [ $# -eq 0 ]; then
#     # echo -e "[INIT] $RED FATAL: No command provided $NC"
#     # exit 1
#     cmd=( "bash" )
# else
#     cmd=( "$@" )
# fi

cmd="jupyterhub-singleuser --ip=\"0.0.0.0\" --port=8889" 

run-hooks () {
    # Source scripts or run executable files in a directory
    if [[ ! -d "$1" ]] ; then
        echo -e "[INIT] $YELLOW No hooks to run in $1 $NC"
        return
    fi
    echo -e "[INIT] $GREEN $0: running hooks in $1 $NC"
    for f in "$1/"*; do
        case "$f" in
            *.sh)
                echo -e "[INIT] $GREEN $0: running $f $NC"
                source "$f"
                ;;
            *)
                if [[ -x "$f" ]] ; then
                    echo -e "[INIT] $GREEN $0: running $f $NC"
                    "$f"
                else
                    echo -e "[INIT] $YELLOW $0: ignoring $f $NC"
                fi
                ;;
        esac
    done
    echo -e "[INIT] $GREEN $0: done running hooks in $1 $NC"
}

run-hooks /usr/local/bin/start-notebook.d

# Enable sudo
echo -e "[INIT] $GREEN Granting $NB_USER sudo access $NC"
echo "$NB_USER ALL=(ALL) NOPASSWD:ALL" | sudo tee -a /etc/sudoers > /dev/null
echo "root ALL=(ALL) ALL" | sudo tee -a /etc/sudoers > /dev/null


# Add $CONDA_DIR/bin to sudo secure_path
# sed -r "s#Defaults\s+secure_path=\"([^\"]+)\"#Defaults secure_path=\"\1:$CONDA_DIR/bin\"#" /etc/sudoers | grep secure_path > /etc/sudoers.d/path
# Exec the command as NB_USER with the PATH and the rest of
# the environment preserved
run-hooks /usr/local/bin/before-notebook.d

echo -e "[INIT] $GREEN Starting nginx $NC"
sudo nginx &

cd /home/$NB_USER
echo -e "[INIT] $GREEN Setting base url in user config $NC"
# echo "c.NotebookApp.base_url = '/jupyter/user/${NB_USER}'" | sudo tee /home/$NB_USER/.jupyter/jupyter_notebook_config.py
echo "c.NotebookApp.default_url = '/lab'" | sudo tee /home/$NB_USER/.jupyter/jupyter_notebook_config.py
echo "c.NotebookApp.allow_origin = '*'" | sudo tee /home/$NB_USER/.jupyter/jupyter_notebook_config.py
sudo chown -R $NB_USER /home/$NB_USER/.jupyter

echo -e "[INIT] $GREEN Starting the server with: ${cmd[@]} $NC"
exec sudo -E -H -u $NB_USER PATH=$PATH XDG_CACHE_HOME=/home/$NB_USER/.cache PYTHONPATH=${PYTHONPATH:-} ${cmd[@]}
#"${cmd[@]}"